@@ -4,7 +4,7 @@ Main interface for codebuild service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_codebuild import (
         Client,
         CodeBuildClient,
@@ -22,10 +22,8 @@ Usage::
         ListSharedReportGroupsPaginator,
     )
 
-    session = boto3.Session()
-
-    client: CodeBuildClient = boto3.client("codebuild")
-    session_client: CodeBuildClient = session.client("codebuild")
+    session = Session()
+    client: CodeBuildClient = session.client("codebuild")
 
     describe_code_coverages_paginator: DescribeCodeCoveragesPaginator = client.get_paginator("describe_code_coverages")
     describe_test_cases_paginator: DescribeTestCasesPaginator = client.get_paginator("describe_test_cases")
